@@ -22,8 +22,9 @@ FILENAMES = {
     'python': (
         '.gitignore',
         '.travis.yml',
-        'AUTHORS',
         'CHANGELOG.md',
+        'CONTRIBUTORS.md',
+        'TODO.md',
         'LICENSE',
         'MANIFEST.in',
         'README.md',
